@@ -23,6 +23,8 @@ from __future__ import absolute_import
 
 from argparse import ArgumentParser
 
+from gevent import sleep
+
 from .core import VERSION
 from .state import SlimtaState
 
@@ -46,9 +48,10 @@ def main():
 
     state.start_celery_queues()
 
-    state.drop_privileges()
     state.redirect_streams()
     state.daemonize()
+    sleep(0.1)
+    state.drop_privileges()
 
     state.worker_loop()
 
